@@ -35,7 +35,7 @@ class SNSMessage(typing.TypedDict):
 
     Message: str
 
-    MessageAttributes: typing.Dict[str, :class:`SNSMessageAttribute`]
+    MessageAttributes: typing.Dict[str, :py:class:`SNSMessageAttribute`]
 
     Type: str
 
@@ -71,7 +71,7 @@ class SNSEventRecord(typing.TypedDict):
 
     EventSource: str
 
-    Sns: :class:`SNSMessage`
+    Sns: :py:class:`SNSMessage`
     """
 
     EventVersion: str
@@ -86,7 +86,7 @@ class SNSEvent(typing.TypedDict):
 
     Attributes:
     ----------
-    Records: typing.List[:class:`SNSEventRecord`]
+    Records: typing.List[:py:class:`SNSEventRecord`]
     """
 
     Records: typing.List[SNSEventRecord]
